@@ -533,6 +533,10 @@ class Task(object):
             :attr:`trail` attribute
         :keyword publisher: Deprecated alias to ``producer``.
 
+        :rtype :class:`celery.result.AsyncResult`: if
+            :setting:`CELERY_ALWAYS_EAGER` is not set, otherwise
+            :class:`celery.result.EagerResult`.
+
         Also supports all keyword arguments supported by
         :meth:`kombu.Producer.publish`.
 
@@ -659,7 +663,7 @@ class Task(object):
                 # first try to reraise the original exception
                 maybe_reraise()
                 # or if not in an except block then raise the custom exc.
-                raise exc()
+                raise exc
             raise self.MaxRetriesExceededError(
                 "Can't retry {0}[{1}] args:{2} kwargs:{3}".format(
                     self.name, request.id, S.args, S.kwargs))
