@@ -4,11 +4,11 @@ import os
 
 from celery import Celery
 
-from django.conf import settings
-
 # set the default Django settings module for the 'celery' program.
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'proj.settings')
 
+from django.conf import settings
+
 app = Celery('proj')
 
 # Using a string here means the worker will not have to
@@ -19,4 +19,4 @@ app.autodiscover_tasks(lambda: settings.INSTALLED_APPS)
 
 @app.task(bind=True)
 def debug_task(self):
-    print(repr(self.request))
+    print('Request: {0!r}'.format(self.request))
